/* This script creates IBPReplicator's configuration in database */

CREATE TABLE REPL$CONFIG (
  CONFLICTMETHOD INTEGER DEFAULT 2 NOT NULL,
  LOGFILENAME VARCHAR2(255 BYTE) DEFAULT 'REPLICATE.LOG' NOT NULL,
  LOGTOFILE INTEGER DEFAULT 3 NOT NULL,
  LOGTOWINDOW INTEGER DEFAULT 3 NOT NULL,
  VERSION INTEGER NOT NULL,
  BKGRNDIMG VARCHAR2(254 BYTE),
  LINKCOLORUNSEL INTEGER,
  LINKCOLORSEL INTEGER,
  DEFAULTSET CHAR(1 BYTE) DEFAULT 'Y' NOT NULL,
  SCHEDULER_ENABLED CHAR(1 BYTE) DEFAULT 'N' NOT NULL,
  ERROR_HOSTNAME VARCHAR2(255 BYTE) DEFAULT '',
  ERROR_FROMADDRESS VARCHAR2(255 BYTE) DEFAULT '',
  ERROR_FROMNAME VARCHAR2(255 BYTE) DEFAULT '',
  ERROR_TOOADDRESS VARCHAR2(255 BYTE) DEFAULT '',
  REPL_BEEP CHAR(1 BYTE) DEFAULT 'N' NOT NULL,
  NOTIFY_ERROR_MESSAGE CHAR(1 BYTE) DEFAULT 'N',
  MAIL_SYSDBA CHAR(1 BYTE) DEFAULT 'N' NOT NULL,
  FPS_TIMEOUT INTEGER DEFAULT 0 NOT NULL,
  FKBEHAVIOR INTEGER DEFAULT 0 NOT NULL)^

CREATE TABLE REPL$DATABASES (
  DBNO INTEGER NOT NULL CONSTRAINT REPL$DATABASES_PK PRIMARY KEY,
  DBPATH VARCHAR2(254 BYTE),
  DBNAME VARCHAR2(100 BYTE) NOT NULL,
  ADMINUSER VARCHAR2(50 BYTE),
  ADMINPASSWD RAW(50),
  COMMENTS VARCHAR2(1000 BYTE),
  PRIORITY INTEGER DEFAULT 0 NOT NULL,
  TIMEFIELDNAME VARCHAR2(100 BYTE),
  CHARSET VARCHAR2(20 BYTE) DEFAULT '',
  DBTYPE INTEGER DEFAULT 0 NOT NULL,
  X INTEGER DEFAULT -1,
  Y INTEGER DEFAULT -1,
  USERROLE VARCHAR2(50 BYTE),
  DIALECT INTEGER DEFAULT 0,
  DIALUSERNAME VARCHAR2(20 BYTE),
  DIALPASSWORD VARCHAR2(20 BYTE),
  RASNAME VARCHAR2(20 BYTE),
  KEEPCONNECTION INTEGER DEFAULT 0 NOT NULL,
  MOREPARAMS CLOB)^

CREATE TABLE REPL$SCHEMATA (
  REPLNO INTEGER NOT NULL CONSTRAINT REPL$SCHEMATA_PK PRIMARY KEY,
  NAME VARCHAR2(100 BYTE) NOT NULL,
  PUBDBNO INTEGER NOT NULL CONSTRAINT REPL$C_SCHEMATA_DATABASE REFERENCES REPL$DATABASES,
  DISABLED CHAR(1 BYTE) DEFAULT 'N',
  COMMENTS VARCHAR2(1000 BYTE),
  USERNAME VARCHAR2(31 BYTE),
  PASSWD RAW(50),
  CONFLICTMETHOD INTEGER DEFAULT 2 NOT NULL,
  USEDEFAULTCONFLICT INTEGER DEFAULT 1 NOT NULL,
  USEDEFAULTLOGGING INTEGER DEFAULT 1 NOT NULL,
  LOGFILENAME VARCHAR2(255 BYTE),
  LOGTOFILE INTEGER DEFAULT 0 NOT NULL,
  LOGTOWINDOW INTEGER DEFAULT 0 NOT NULL,
  SEP INTEGER DEFAULT 9 NOT NULL,
  USERROLE VARCHAR2(50 BYTE),
  SORT_KEY INTEGER)^

CREATE TABLE REPL$FIELDS (
  REPLNO INTEGER NOT NULL,
  TGTDBNO INTEGER NOT NULL,
  RELATIONNO INTEGER NOT NULL,
  FIELDNO INTEGER NOT NULL,
  IS_DATA INTEGER DEFAULT 1 NOT NULL,
  FIELDNAME VARCHAR2(100 BYTE) NOT NULL,
  TARGETNAME VARCHAR2(100 BYTE) NOT NULL,
  CONSTRAINT REPL$KF_PK PRIMARY KEY (REPLNO, TGTDBNO, RELATIONNO, FIELDNO))^

CREATE TABLE REPL$RELATIONS (REPLNO INTEGER NOT NULL,
  RELATIONNO INTEGER NOT NULL,
  RELATIONSCHEMA VARCHAR2(100 BYTE),
  RELATIONNAME VARCHAR2(100 BYTE) NOT NULL,
  COMMENTS VARCHAR2(1000 BYTE),
  DISABLED CHAR(1 BYTE) DEFAULT 'N',
  TIMEFIELDNAME VARCHAR2(100 BYTE),
  CONDITION VARCHAR2(255 BYTE) DEFAULT '',
  TGTDBNO INTEGER NOT NULL,
  TARGETSCHEMA VARCHAR2(100 BYTE),
  TARGETNAME VARCHAR2(100 BYTE) NOT NULL,
  TARGETTYPE CHAR(1 BYTE) DEFAULT 'T' NOT NULL,
  SEP INTEGER DEFAULT 9 NOT NULL,
  INSERTS INTEGER DEFAULT 0 NOT NULL,
  UPDATES INTEGER DEFAULT 0 NOT NULL,
  DELETES INTEGER DEFAULT 0 NOT NULL,
  KEEPSTATS INTEGER DEFAULT 0 NOT NULL,
  CONFLICTS INTEGER DEFAULT 0 NOT NULL,
  SORT_KEY INTEGER,
  OPS CHAR(3 BYTE) DEFAULT 'UID',
  CONFLICTMETHOD INTEGER DEFAULT -1 NOT NULL,
  FKBEHAVIOR INTEGER DEFAULT -1 NOT NULL,
  CONSTRAINT REPL$RELATIONS_PK PRIMARY KEY (REPLNO, TGTDBNO, RELATIONNO))^

CREATE TABLE REPL$SCHEDULE (
  ID INTEGER NOT NULL CONSTRAINT REPL$SCHEDULE_PK PRIMARY KEY,
  FREQUENCY INTEGER NOT NULL,
  ENABLED CHAR(1 BYTE) DEFAULT 'Y' NOT NULL,
  INT_VALUE INTEGER,
  TIME_VALUE VARCHAR2(8 BYTE),
  DATE_VALUE VARCHAR2(20 BYTE))^
  
CREATE TABLE REPL$SUBSCRIBEDDB (
  REPLNO INTEGER NOT NULL,
  DBNO INTEGER NOT NULL,
  USERNAME VARCHAR2(31 BYTE),
  PASSWD RAW(50),
  USERROLE VARCHAR2(50 BYTE),
  COMMITCOUNT INTEGER DEFAULT 0 NOT NULL,
  CONDITION VARCHAR2(255 BYTE) DEFAULT '',
  USEDEFAULTLOGGING INTEGER DEFAULT 1 NOT NULL,
  LOGFILENAME VARCHAR2(255 BYTE),
  LOGTOFILE INTEGER DEFAULT 0 NOT NULL,
  LOGTOWINDOW INTEGER DEFAULT 0 NOT NULL,
  SORT_KEY INTEGER,
  CONSTRAINT REPL$SUBSCRIBEDDB_PK PRIMARY KEY (REPLNO, DBNO))^

CREATE TABLE REPL$SEQUENCES (
  REPLNO INTEGER NOT NULL,
  TGTDBNO INTEGER NOT NULL,
  SEQNO INTEGER NOT NULL CONSTRAINT REPL$SEQ_PK PRIMARY KEY,
  SOURCESCHEMA VARCHAR2(100 BYTE) DEFAULT '',
  SOURCENAME VARCHAR2(100 BYTE) NOT NULL,
  TARGETSCHEMA VARCHAR2(100 BYTE) DEFAULT '',
  TARGETNAME VARCHAR2(100 BYTE) NOT NULL,
  CONSTRAINT REPL$C_SEQ_SUBSCRIBED FOREIGN KEY (REPLNO, TGTDBNO) REFERENCES REPL$SUBSCRIBEDDB)^

CREATE TABLE REPL$LICENSES (LICENSENO INTEGER NOT NULL CONSTRAINT REPL$LICENSES_PK PRIMARY KEY,LICENSEID VARCHAR(15 BYTE) NOT NULL,LICENSEKEY3 VARCHAR(300 BYTE) NOT NULL)^

CREATE TABLE REPL$KEYWORDS (
  DBMS INTEGER NOT NULL,
  WORD VARCHAR2(31 BYTE) NOT NULL)^

INSERT INTO REPL$KEYWORDS VALUES (0,'ACTION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ACTIVE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ADD')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ADMIN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'AFTER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ALL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ALTER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'AND')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ANY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'AS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ASC')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ASCENDING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'AT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'AUTO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'AUTODDL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'AVG')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BASED')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BASENAME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BASE_NAME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BEFORE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BEGIN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BETWEEN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BLOB')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BLOBEDIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BUFFER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'BY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CACHE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CASCADE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CAST')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CHAR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CHARACTER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CHARACTER_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CHAR_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CHECK')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CHECK_POINT_LEN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CHECK_POINT_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COLLATE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COLLATION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COLUMN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COMMIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COMMITTED')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COMPILETIME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COMPUTED')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CLOSE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CONDITIONAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CONNECT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CONSTRAINT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CONTAINING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CONTINUE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'COUNT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CREATE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CSTRING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CURRENT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CURRENT_DATE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CURRENT_TIME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CURRENT_TIMESTAMP')^
INSERT INTO REPL$KEYWORDS VALUES (0,'CURSOR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DATABASE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DATE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DAY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DB_KEY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DEBUG')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DEC')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DECIMAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DECLARE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DEFAULT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DELETE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DESC')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DESCENDING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DESCRIBE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DESCRIPTOR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DISCONNECT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DISPLAY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DISTINCT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DOMAIN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DOUBLE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'DROP')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ECHO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EDIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ELSE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'END')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ENTRY_POINT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ESCAPE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EVENT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EXCEPTION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EXECUTE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EXISTS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EXIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EXTERN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EXTERNAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'EXTRACT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FETCH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FILE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FILTER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FLOAT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FOR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FOREIGN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FOUND')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FREE_IT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FROM')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FULL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'FUNCTION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GDSCODE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GENERATOR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GEN_ID')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GLOBAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GOTO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GRANT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GROUP')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GROUP_COMMIT_WAIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'GROUP_COMMIT_WAIT_TIME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'HAVING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'HELP')^
INSERT INTO REPL$KEYWORDS VALUES (0,'HOUR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'IF')^
INSERT INTO REPL$KEYWORDS VALUES (0,'IMMEDIATE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'IN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INACTIVE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INDEX')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INDICATOR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INNER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INPUT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INPUT_TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INSERT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INTEGER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'INTO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'IS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ISOLATION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ISQL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'JOIN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'KEY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LC_MESSAGES')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LC_TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LEFT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LEV')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LEVEL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LIKE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LOGFILE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LOG_BUFFER_SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LOG_BUF_SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'LONG')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MANUAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MAX')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MAXIMUM')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MAXIMUM_SEGMENT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MAX_SEGMENT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MERGE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MESSAGE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MIN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MINIMUM')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MINUTE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MODULE_NAME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'MONTH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NAMES')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NATIONAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NATURAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NCHAR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NOAUTO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NOT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NULL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NUMERIC')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NUM_LOG_BUFS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'NUM_LOG_BUFFERS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OCTET_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OF')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ON')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ONLY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OPEN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OPTION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ORDER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OUTER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OUTPUT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OUTPUT_TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'OVERFLOW')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PAGE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PAGELENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PAGES')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PAGE_SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PARAMETER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PASSWORD')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PLAN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'POSITION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'POST_EVENT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PRECISION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PREPARE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PRIMARY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PRIVILEGES')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PROCEDURE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PROTECTED')^
INSERT INTO REPL$KEYWORDS VALUES (0,'PUBLIC')^
INSERT INTO REPL$KEYWORDS VALUES (0,'QUIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RAW_PARTITIONS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RDB$DB_KEY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'READ')^
INSERT INTO REPL$KEYWORDS VALUES (0,'REAL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RECORD_VERSION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'REFERENCES')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RELEASE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RESERV')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RESERVING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RESTRICT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RETAIN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RETURN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RETURNING_VALUES')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RETURNS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'REVOKE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RIGHT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ROLE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ROLLBACK')^
INSERT INTO REPL$KEYWORDS VALUES (0,'RUNTIME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'ROWS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SAVEPOINT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SCHEMA')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SECOND')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SEGMENT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SELECT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SET')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SHADOW')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SHARED')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SHELL')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SHOW')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SINGULAR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SMALLINT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SNAPSHOT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SOME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SORT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SQLCODE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SQLERROR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SQLWARNING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'STABILITY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'STARTING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'STARTS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'START')^
INSERT INTO REPL$KEYWORDS VALUES (0,'STATEMENT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'STATIC')^
INSERT INTO REPL$KEYWORDS VALUES (0,'STATISTICS')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SUB_TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SUM')^
INSERT INTO REPL$KEYWORDS VALUES (0,'SUSPEND')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TABLE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TERMINATOR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'THEN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TIME')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TIMESTAMP')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TO')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TRANSACTION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TRANSLATE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TRANSLATION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TRIGGER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TRIM')^
INSERT INTO REPL$KEYWORDS VALUES (0,'TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'UNCOMMITTED')^
INSERT INTO REPL$KEYWORDS VALUES (0,'UNION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'UNIQUE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'UPDATE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'UPPER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'USER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'USING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'VALUE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'VALUES')^
INSERT INTO REPL$KEYWORDS VALUES (0,'VARCHAR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'VARIABLE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'VARYING')^
INSERT INTO REPL$KEYWORDS VALUES (0,'VERSION')^
INSERT INTO REPL$KEYWORDS VALUES (0,'VIEW')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WAIT')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WEEKDAY')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WHEN')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WHENEVER')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WHERE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WHILE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WITH')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WORK')^
INSERT INTO REPL$KEYWORDS VALUES (0,'WRITE')^
INSERT INTO REPL$KEYWORDS VALUES (0,'YEAR')^
INSERT INTO REPL$KEYWORDS VALUES (0,'YEARDAY')^

INSERT INTO REPL$KEYWORDS VALUES (1,'ACCESS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ADD')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ALL')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ALTER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'AND')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ANY')^
INSERT INTO REPL$KEYWORDS VALUES (1,'AS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ASC')^
INSERT INTO REPL$KEYWORDS VALUES (1,'AUDIT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'BETWEEN')^
INSERT INTO REPL$KEYWORDS VALUES (1,'BY')^
INSERT INTO REPL$KEYWORDS VALUES (1,'CHAR')^
INSERT INTO REPL$KEYWORDS VALUES (1,'CHECK')^
INSERT INTO REPL$KEYWORDS VALUES (1,'CLUSTER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'COLUMN')^
INSERT INTO REPL$KEYWORDS VALUES (1,'COMMENT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'COMPRESS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'CONNECT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'CREATE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'CURRENT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'DATE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'DECIMAL')^
INSERT INTO REPL$KEYWORDS VALUES (1,'DEFAULT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'DELETE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'DESC')^
INSERT INTO REPL$KEYWORDS VALUES (1,'DISTINCT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'DROP')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ELSE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'EXCLUSIVE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'EXISTS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'FILE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'FLOAT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'FOR')^
INSERT INTO REPL$KEYWORDS VALUES (1,'FROM')^
INSERT INTO REPL$KEYWORDS VALUES (1,'GRANT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'GROUP')^
INSERT INTO REPL$KEYWORDS VALUES (1,'HAVING')^
INSERT INTO REPL$KEYWORDS VALUES (1,'IDENTIFIED')^
INSERT INTO REPL$KEYWORDS VALUES (1,'IMMEDIATE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'IN')^
INSERT INTO REPL$KEYWORDS VALUES (1,'INCREMENT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'INDEX')^
INSERT INTO REPL$KEYWORDS VALUES (1,'INITIAL')^
INSERT INTO REPL$KEYWORDS VALUES (1,'INSERT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'INTEGER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'INTERSECT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'INTO')^
INSERT INTO REPL$KEYWORDS VALUES (1,'IS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'LEVEL')^
INSERT INTO REPL$KEYWORDS VALUES (1,'LIKE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'LOCK')^
INSERT INTO REPL$KEYWORDS VALUES (1,'LONG')^
INSERT INTO REPL$KEYWORDS VALUES (1,'MAXEXTENTS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'MINUS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'MLSLABEL')^
INSERT INTO REPL$KEYWORDS VALUES (1,'MODE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'MODIFY')^
INSERT INTO REPL$KEYWORDS VALUES (1,'NOAUDIT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'NOCOMPRESS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'NOT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'NOWAIT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'NULL')^
INSERT INTO REPL$KEYWORDS VALUES (1,'NUMBER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'OF')^
INSERT INTO REPL$KEYWORDS VALUES (1,'OFFLINE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ON')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ONLINE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'OPTION')^
INSERT INTO REPL$KEYWORDS VALUES (1,'OR')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ORDER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'PCTFREE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'PRIOR')^
INSERT INTO REPL$KEYWORDS VALUES (1,'PRIVILEGES')^
INSERT INTO REPL$KEYWORDS VALUES (1,'PUBLIC')^
INSERT INTO REPL$KEYWORDS VALUES (1,'RAW')^
INSERT INTO REPL$KEYWORDS VALUES (1,'RENAME')^
INSERT INTO REPL$KEYWORDS VALUES (1,'RESOURCE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'REVOKE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ROW')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ROWID')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ROWNUM')^
INSERT INTO REPL$KEYWORDS VALUES (1,'ROWS')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SELECT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SESSION')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SET')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SHARE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SMALLINT')^
INSERT INTO REPL$KEYWORDS VALUES (1,'START')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SUCCESSFUL')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SYNONYM')^
INSERT INTO REPL$KEYWORDS VALUES (1,'SYSDATE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'TABLE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'THEN')^
INSERT INTO REPL$KEYWORDS VALUES (1,'TO')^
INSERT INTO REPL$KEYWORDS VALUES (1,'TRIGGER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'UID')^
INSERT INTO REPL$KEYWORDS VALUES (1,'UNION')^
INSERT INTO REPL$KEYWORDS VALUES (1,'UNIQUE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'UPDATE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'USER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'VALIDATE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'VALUES')^
INSERT INTO REPL$KEYWORDS VALUES (1,'VARCHAR')^
INSERT INTO REPL$KEYWORDS VALUES (1,'VARCHAR2')^
INSERT INTO REPL$KEYWORDS VALUES (1,'VIEW')^
INSERT INTO REPL$KEYWORDS VALUES (1,'WHENEVER')^
INSERT INTO REPL$KEYWORDS VALUES (1,'WHERE')^
INSERT INTO REPL$KEYWORDS VALUES (1,'WITH')^

INSERT INTO REPL$KEYWORDS VALUES (3,'ACTION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ACTIVE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ADD')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ADMIN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'AFTER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ALL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ALTER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'AND')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ANY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'AS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ASC')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ASCENDING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'AT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'AUTO')^
INSERT INTO REPL$KEYWORDS VALUES (3,'AVG')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BASE_NAME')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BEFORE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BEGIN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BETWEEN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BIGINT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BLOB')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BLOCK')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BREAK')^
INSERT INTO REPL$KEYWORDS VALUES (3,'BY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CACHE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CASCADE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CASE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CAST')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CHAR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CHAR_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CHARACTER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CHARACTER_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CHECK')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CHECK_POINT_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CLOSE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'COALESCE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'COLLATE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'COLUMN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'COMMIT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'COMMITTED')^
INSERT INTO REPL$KEYWORDS VALUES (3,'COMPUTED')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CONDITIONAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CONNECT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CONSTRAINT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CONTAINING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'COUNT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CREATE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CROSS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CSTRING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT_CONNECTION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT_DATE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT_ROLE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT_TIME')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT_TIMESTAMP')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT_TRANSACTION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURRENT_USER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'CURSOR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DATABASE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DATE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DAY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DEBUG')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DEC')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DECIMAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DECLARE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DEFAULT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DELETE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DELETING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DESC')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DESCENDING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DESCRIPTOR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DIFFERENCE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DISCONNECT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DISTINCT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DO')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DOMAIN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DOUBLE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'DROP')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ELSE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'END')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ENTRY_POINT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ESCAPE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'EXCEPTION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'EXECUTE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'EXISTS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'EXIT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'EXTERNAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'EXTRACT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FETCH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FILE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FILTER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FIRST')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FLOAT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FOR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FOREIGN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FREE_IT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FROM')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FULL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'FUNCTION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'GDSCODE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'GENERATOR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'GEN_ID')^
INSERT INTO REPL$KEYWORDS VALUES (3,'GLOBAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'GRANT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'GROUP')^
INSERT INTO REPL$KEYWORDS VALUES (3,'GROUP_COMMIT_WAIT_TIME')^
INSERT INTO REPL$KEYWORDS VALUES (3,'HAVING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'HOUR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'IF')^
INSERT INTO REPL$KEYWORDS VALUES (3,'IIF')^
INSERT INTO REPL$KEYWORDS VALUES (3,'IN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INACTIVE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INDEX')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INNER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INPUT_TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INSENSITIVE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INSERT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INSERTING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INTEGER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'INTO')^
INSERT INTO REPL$KEYWORDS VALUES (3,'IS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ISOLATION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'JOIN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'KEY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LAST')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LEADING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LEAVE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LEFT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LEVEL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LIKE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LIST')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LOGFILE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LOG_BUFFER_SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LONG')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LOWER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MANUAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MATCHED')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MATCHING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MAX')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MAXIMUM_SEGMENT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MERGE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MESSAGE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MIN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MINUTE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MODULE_NAME')^
INSERT INTO REPL$KEYWORDS VALUES (3,'MONTH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NAMES')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NATIONAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NATURAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NCHAR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NEXT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NO')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NOT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NULLIF')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NULL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NULLS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'LOCK')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NUMERIC')^
INSERT INTO REPL$KEYWORDS VALUES (3,'NUM_LOG_BUFFERS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OCTET_LENGTH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OF')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ON')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ONLY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OPEN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OPTION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ORDER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OUTER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OUTPUT_TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'OVERFLOW')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PAGE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PAGES')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PAGE_SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PARAMETER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PASSWORD')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PLAN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'POSITION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'POST_EVENT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PRECISION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PRESERVE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PRIMARY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PRIVILEGES')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PROCEDURE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'PROTECTED')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RAW_PARTITIONS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RDB$DB_KEY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'READ')^
INSERT INTO REPL$KEYWORDS VALUES (3,'REAL')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RECORD_VERSION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RECREATE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RECURSIVE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'REFERENCES')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RELEASE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RESERV')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RESERVING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RESTART')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RESTRICT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RETAIN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RETURNING_VALUES')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RETURNS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'REVOKE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'RIGHT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ROLE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ROLLBACK')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ROW_COUNT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'ROWS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SAVEPOINT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SCALAR_ARRAY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SCHEMA')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SECOND')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SEGMENT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SELECT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SENSITIVE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SEQUENCE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SET')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SHADOW')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SHARED')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SINGULAR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SIZE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SKIP')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SMALLINT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SNAPSHOT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SOME')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SORT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SQLCODE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'STABILITY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'STARTING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'STARTS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'START')^
INSERT INTO REPL$KEYWORDS VALUES (3,'STATEMENT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'STATISTICS')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SUBSTRING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SUB_TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SUM')^
INSERT INTO REPL$KEYWORDS VALUES (3,'SUSPEND')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TABLE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TEMPORARY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'THEN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TIME')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TIMESTAMP')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TO')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TRAILING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TRANSACTION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TRIGGER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TRIM')^
INSERT INTO REPL$KEYWORDS VALUES (3,'TYPE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'UNCOMMITTED')^
INSERT INTO REPL$KEYWORDS VALUES (3,'UNION')^
INSERT INTO REPL$KEYWORDS VALUES (3,'UNIQUE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'UPDATE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'UPDATING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'UPPER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'USER')^
INSERT INTO REPL$KEYWORDS VALUES (3,'USING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'VALUE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'VALUES')^
INSERT INTO REPL$KEYWORDS VALUES (3,'VARCHAR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'VARIABLE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'VARYING')^
INSERT INTO REPL$KEYWORDS VALUES (3,'VIEW')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WAIT')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WEEKDAY')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WHEN')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WHERE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WHILE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WITH')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WORK')^
INSERT INTO REPL$KEYWORDS VALUES (3,'WRITE')^
INSERT INTO REPL$KEYWORDS VALUES (3,'YEAR')^
INSERT INTO REPL$KEYWORDS VALUES (3,'YEARDAY')^

ALTER TABLE REPL$SUBSCRIBEDDB ADD CONSTRAINT REPL$C_SUBSCRIBED_DB FOREIGN KEY (DBNO) REFERENCES REPL$DATABASES(DBNO)^
ALTER TABLE REPL$SUBSCRIBEDDB ADD CONSTRAINT REPL$C_SUBSCRIBED_SCHEMATA FOREIGN KEY (REPLNO) REFERENCES REPL$SCHEMATA(REPLNO)^
ALTER TABLE REPL$RELATIONS ADD CONSTRAINT REPL$C_RELATION_SUBSCRIBED FOREIGN KEY (REPLNO, TGTDBNO) REFERENCES REPL$SUBSCRIBEDDB^
ALTER TABLE REPL$FIELDS ADD CONSTRAINT REPL$C_FIELDS_RELATIONS FOREIGN KEY (REPLNO, TGTDBNO, RELATIONNO) REFERENCES REPL$RELATIONS(REPLNO, TGTDBNO, RELATIONNO)^

CREATE SEQUENCE REPL$GEN^
CREATE SEQUENCE REPL$DBGEN^
CREATE SEQUENCE REPL$RELATIONGEN^
CREATE SEQUENCE REPL$SCHED_GEN^

CREATE PROCEDURE REPL$CLONETARGET (OLDREPLNO IN INTEGER, OLDTGTDBNO IN INTEGER, NEWREPLNO IN INTEGER, NEWTGTDBNO IN INTEGER)
AS
  NEWRLNNO INTEGER;
  NEWSORTKEY INTEGER;
  SUBDBCOUNT INTEGER;
BEGIN
  select COUNT(*) INTO SUBDBCOUNT from REPL$subscribeddb where replno = newreplno and dbno = newtgtdbno;
  IF SUBDBCOUNT = 0 THEN
    BEGIN
     select MAX(SORT_KEY)+1 INTO NEWSORTKEY FROM REPL$SUBSCRIBEDDB WHERE REPLNO=NEWREPLNO;
    EXCEPTION
     WHEN NO_DATA_FOUND THEN
       NEWSORTKEY := 0;
    END;
    insert into REPL$subscribeddb(replno,dbno,username,passwd,userrole,UseDefaultLogging,LogFileName,LogToFile,LogToWindow,sort_key)
    select newreplno,newtgtdbno,username,passwd,userrole,UseDefaultLogging,LogFileName,LogToFile,LogToWindow,newsortkey from REPL$subscribeddb where replno = OLDreplno and dbno = OLDtgtdbno;
  end if;
  FOR Relation in (SELECT RELATIONNO FROM REPL$RELATIONS WHERE REPLNO = OLDREPLNO AND TGTDBNO = OLDTGTDBNO)
  LOOP
    SELECT REPL$RELATIONGEN.Nextval INTO NEWRLNNO FROM DUAL;
    INSERT INTO REPL$RELATIONS (REPLNO,TGTDBNO,RELATIONNO,RELATIONSCHEMA,RELATIONNAME,COMMENTS,DISABLED,TIMEFIELDNAME,CONDITION,TARGETSCHEMA,TARGETNAME,TARGETTYPE,SEP,OPS,SORT_KEY,CONFLICTMETHOD,FKBEHAVIOR)
    SELECT NEWREPLNO,NEWTGTDBNO,NEWRLNNO,RELATIONSCHEMA,RELATIONNAME,COMMENTS,DISABLED,TIMEFIELDNAME,CONDITION,TARGETSCHEMA,TARGETNAME,TARGETTYPE,SEP,OPS,SORT_KEY,CONFLICTMETHOD,FKBEHAVIOR FROM REPL$RELATIONS
      WHERE REPLNO = OLDREPLNO AND TGTDBNO = OLDTGTDBNO AND RELATIONNO = Relation.RELATIONNO;
    INSERT INTO REPL$FIELDS (REPLNO, RELATIONNO, TGTDBNO, FIELDNO, IS_DATA, FIELDNAME, TARGETNAME)
    SELECT NEWREPLNO, NEWRLNNO, NEWTGTDBNO, FIELDNO, IS_DATA, FIELDNAME, TARGETNAME FROM REPL$FIELDS
      WHERE REPLNO = OLDREPLNO AND TGTDBNO = OLDTGTDBNO AND RELATIONNO = Relation.RELATIONNO;
  END LOOP;
  INSERT INTO REPL$SEQUENCES (REPLNO,TGTDBNO,SOURCESCHEMA,SOURCENAME,TARGETSCHEMA,TARGETNAME)
    SELECT NEWREPLNO,NEWTGTDBNO,SOURCESCHEMA,SOURCENAME,TARGETSCHEMA,TARGETNAME FROM REPL$SEQUENCES
      WHERE REPLNO=OLDREPLNO AND TGTDBNO=OLDTGTDBNO;
END;^

CREATE TRIGGER REPL$SETREPLNO BEFORE INSERT ON REPL$SCHEMATA FOR EACH ROW
WHEN (NEW.REPLNO IS NULL)
BEGIN 
  SELECT REPL$GEN.NextVal INTO :NEW.REPLNO FROM DUAL; 
END;^

CREATE TRIGGER REPL$SETDBNO BEFORE INSERT ON REPL$DATABASES FOR EACH ROW
WHEN (NEW.DBNO IS NULL)
BEGIN 
  SELECT REPL$DBGEN.NextVal INTO :NEW.DBNO FROM DUAL; 
END;^

CREATE TRIGGER REPL$SETRELATIONNO BEFORE INSERT ON REPL$RELATIONS FOR EACH ROW
WHEN (NEW.RELATIONNO IS NULL)
BEGIN 
  SELECT REPL$RELATIONGEN.NextVal INTO :NEW.RELATIONNO FROM DUAL;
END;^

CREATE TRIGGER REPL$SETSEQUENCENO BEFORE INSERT ON REPL$SEQUENCES FOR EACH ROW
WHEN (NEW.SEQNO IS NULL)
BEGIN 
  SELECT REPL$RELATIONGEN.NextVal INTO :NEW.SEQNO FROM DUAL;
END;^

CREATE TRIGGER REPL$CASCADEDBDELETE BEFORE DELETE ON REPL$DATABASES FOR EACH ROW
BEGIN 
  DELETE FROM REPL$SUBSCRIBEDDB WHERE DBNO = :OLD.DBNO; 
  DELETE FROM REPL$SCHEMATA WHERE PUBDBNO = :OLD.DBNO;
END;^

CREATE TRIGGER REPL$CASCADERELATIONDELETE BEFORE DELETE ON REPL$RELATIONS FOR EACH ROW
BEGIN 
  DELETE FROM REPL$FIELDS WHERE REPLNO = :OLD.REPLNO AND TGTDBNO = :OLD.TGTDBNO AND RELATIONNO = :OLD.RELATIONNO;
END;^

CREATE TRIGGER REPL$CASCADEPUBLISHEDDELETE BEFORE DELETE ON REPL$SCHEMATA FOR EACH ROW
BEGIN
 DELETE FROM REPL$RELATIONS WHERE REPLNO=:OLD.REPLNO;
 DELETE FROM REPL$SEQUENCES WHERE REPLNO=:OLD.REPLNO;
 DELETE FROM REPL$SUBSCRIBEDDB WHERE REPLNO=:OLD.REPLNO;
END;^

CREATE SEQUENCE REPL$LICENSEGEN^

CREATE TRIGGER REPL$LICENSEINS BEFORE INSERT ON REPL$LICENSES FOR EACH ROW
WHEN (NEW.LICENSENO IS NULL)
BEGIN
  SELECT REPL$LICENSEGEN.NextVal INTO :NEW.LICENSENO FROM DUAL; 
END;^

CREATE TRIGGER REPL$LICENSE_DEL BEFORE DELETE ON REPL$LICENSES FOR EACH ROW WHEN (UPPER(OLD.LICENSEID)='EVAL')
BEGIN RAISE_APPLICATION_ERROR(-20000,'Evaluation licence cannot be deleted'); END;^

INSERT INTO REPL$CONFIG(VERSION) VALUES(41)^
