/* This script upgrades Oracle configuration database v4.0 to v4.1 */

ALTER TABLE REPL$RELATIONS
 ADD (CONFLICTMETHOD INTEGER DEFAULT -1 NOT NULL,
      FKBEHAVIOR INTEGER DEFAULT -1 NOT NULL)^

ALTER TABLE REPL$DATABASES ADD ADMINPASSWD RAW(50)^
ALTER TABLE REPL$SCHEMATA ADD PASSWD RAW(50)^
ALTER TABLE REPL$SUBSCRIBEDDB ADD PASSWD RAW(50)^

CREATE TABLE REPL$SEQUENCES (
  REPLNO INTEGER NOT NULL,
  TGTDBNO INTEGER NOT NULL,
  SEQNO INTEGER NOT NULL CONSTRAINT REPL$SEQ_PK PRIMARY KEY,
  SOURCESCHEMA VARCHAR2(100 BYTE) DEFAULT '',
  SOURCENAME VARCHAR2(100 BYTE) NOT NULL,
  TARGETSCHEMA VARCHAR2(100 BYTE) DEFAULT '',
  TARGETNAME VARCHAR2(100 BYTE) NOT NULL,
  CONSTRAINT REPL$C_SEQ_SUBSCRIBED FOREIGN KEY (REPLNO, TGTDBNO) REFERENCES REPL$SUBSCRIBEDDB)^

CREATE TRIGGER REPL$SETSEQUENCENO BEFORE INSERT ON REPL$SEQUENCES FOR EACH ROW
WHEN (NEW.SEQNO IS NULL)
BEGIN 
  SELECT REPL$RELATIONGEN.NextVal INTO :NEW.SEQNO FROM DUAL;
END;^

CREATE OR REPLACE TRIGGER REPL$CASCADEPUBLISHEDDELETE BEFORE DELETE ON REPL$SCHEMATA FOR EACH ROW
BEGIN
 DELETE FROM REPL$RELATIONS WHERE REPLNO=:OLD.REPLNO;
 DELETE FROM REPL$SEQUENCES WHERE REPLNO=:OLD.REPLNO;
 DELETE FROM REPL$SUBSCRIBEDDB WHERE REPLNO=:OLD.REPLNO;
END;^

CREATE OR REPLACE PROCEDURE REPL$CLONETARGET (OLDREPLNO IN INTEGER, OLDTGTDBNO IN INTEGER, NEWREPLNO IN INTEGER, NEWTGTDBNO IN INTEGER)
AS
  NEWRLNNO INTEGER;
  NEWSORTKEY INTEGER;
  SUBDBCOUNT INTEGER;
BEGIN
  select COUNT(*) INTO SUBDBCOUNT from REPL$subscribeddb where replno = newreplno and dbno = newtgtdbno;
  IF SUBDBCOUNT = 0 THEN
    BEGIN
     select MAX(SORT_KEY)+1 INTO NEWSORTKEY FROM REPL$SUBSCRIBEDDB WHERE REPLNO=NEWREPLNO;
    EXCEPTION
     WHEN NO_DATA_FOUND THEN
       NEWSORTKEY := 0;
    END;
    insert into REPL$subscribeddb(replno,dbno,username,passwd,userrole,UseDefaultLogging,LogFileName,LogToFile,LogToWindow,sort_key)
    select newreplno,newtgtdbno,username,passwd,userrole,UseDefaultLogging,LogFileName,LogToFile,LogToWindow,newsortkey from REPL$subscribeddb where replno = OLDreplno and dbno = OLDtgtdbno;
  end if;
  FOR Relation in (SELECT RELATIONNO FROM REPL$RELATIONS WHERE REPLNO = OLDREPLNO AND TGTDBNO = OLDTGTDBNO)
  LOOP
    SELECT REPL$RELATIONGEN.Nextval INTO NEWRLNNO FROM DUAL;
    INSERT INTO REPL$RELATIONS (REPLNO,TGTDBNO,RELATIONNO,RELATIONSCHEMA,RELATIONNAME,COMMENTS,DISABLED,TIMEFIELDNAME,CONDITION,TARGETSCHEMA,TARGETNAME,TARGETTYPE,SEP,OPS,SORT_KEY,CONFLICTMETHOD,FKBEHAVIOR)
    SELECT NEWREPLNO,NEWTGTDBNO,NEWRLNNO,RELATIONSCHEMA,RELATIONNAME,COMMENTS,DISABLED,TIMEFIELDNAME,CONDITION,TARGETSCHEMA,TARGETNAME,TARGETTYPE,SEP,OPS,SORT_KEY,CONFLICTMETHOD,FKBEHAVIOR FROM REPL$RELATIONS
      WHERE REPLNO = OLDREPLNO AND TGTDBNO = OLDTGTDBNO AND RELATIONNO = Relation.RELATIONNO;
    INSERT INTO REPL$FIELDS (REPLNO, RELATIONNO, TGTDBNO, FIELDNO, IS_DATA, FIELDNAME, TARGETNAME)
    SELECT NEWREPLNO, NEWRLNNO, NEWTGTDBNO, FIELDNO, IS_DATA, FIELDNAME, TARGETNAME FROM REPL$FIELDS
      WHERE REPLNO = OLDREPLNO AND TGTDBNO = OLDTGTDBNO AND RELATIONNO = Relation.RELATIONNO;
  END LOOP;
  INSERT INTO REPL$SEQUENCES (REPLNO,TGTDBNO,SOURCESCHEMA,SOURCENAME,TARGETSCHEMA,TARGETNAME)
    SELECT NEWREPLNO,NEWTGTDBNO,SOURCESCHEMA,SOURCENAME,TARGETSCHEMA,TARGETNAME FROM REPL$SEQUENCES
      WHERE REPLNO=OLDREPLNO AND TGTDBNO=OLDTGTDBNO;
END;^

/* Following block can work properly only if client character set match DB character set */
UPDATE REPL$DATABASES SET ADMINPASSWD=UTL_RAW.CAST_TO_RAW(ADMINPASSWORD)^
UPDATE REPL$SCHEMATA SET PASSWD=UTL_RAW.CAST_TO_RAW(PSWORD)^
UPDATE REPL$SUBSCRIBEDDB SET PASSWD=UTL_RAW.CAST_TO_RAW(PSWORD)^

/* Reset connection character set for Oracle databases */
UPDATE REPL$DATABASES SET CHARSET='' WHERE DBTYPE=1^

/* These commands are executed later by ReplManager itself */
/* ALTER TABLE REPL$DATABASES DROP COLUMN ADMINPASSWORD^ */
/* ALTER TABLE REPL$SCHEMATA DROP COLUMN PSWORD^ */
/* ALTER TABLE REPL$SUBSCRIBEDDB DROP COLUMN PSWORD^ */

UPDATE REPL$CONFIG SET VERSION=41^
