/* This script upgrades configuration database v4.0 to v4.1 */

ALTER TABLE REPL$RELATIONS
 ADD CONFLICTMETHOD INTEGER DEFAULT -1 NOT NULL,
 ADD FKBEHAVIOR INTEGER DEFAULT -1 NOT NULL^

UPDATE REPL$RELATIONS SET CONFLICTMETHOD=-1^
UPDATE REPL$RELATIONS SET FKBEHAVIOR=-1^

/* Reset connection character set for Oracle databases */
UPDATE REPL$DATABASES SET CHARSET='' WHERE DBTYPE=1^

CREATE TABLE REPL$SEQUENCES (
  REPLNO INTEGER NOT NULL,
  TGTDBNO INTEGER NOT NULL,
  SEQNO INTEGER NOT NULL CONSTRAINT REPL$SEQ_PK PRIMARY KEY,
  SOURCESCHEMA VARCHAR(100) CHARACTER SET NONE DEFAULT '' NOT NULL,
  SOURCENAME VARCHAR(100) CHARACTER SET NONE NOT NULL,
  TARGETSCHEMA VARCHAR(100) CHARACTER SET NONE DEFAULT '' NOT NULL,
  TARGETNAME VARCHAR(100) CHARACTER SET NONE NOT NULL,
  CONSTRAINT REPL$C_SEQ_SUBSCRIBED FOREIGN KEY (REPLNO, TGTDBNO) REFERENCES REPL$SUBSCRIBEDDB)^

CREATE TRIGGER REPL$SETSEQENCENO FOR REPL$SEQUENCES
ACTIVE BEFORE INSERT POSITION 0 
AS 
BEGIN 
  IF (NEW.SEQNO IS NULL) THEN 
    NEW.SEQNO = GEN_ID(REPL$RELATIONGEN,1);
END^

ALTER TRIGGER REPL$CASCADEPUBLISHEDDELETE
ACTIVE BEFORE DELETE POSITION 0 
AS 
BEGIN
 DELETE FROM REPL$RELATIONS WHERE REPLNO=OLD.REPLNO;
 DELETE FROM REPL$SEQUENCES WHERE REPLNO=OLD.REPLNO;
 DELETE FROM REPL$SUBSCRIBEDDB WHERE REPLNO=OLD.REPLNO;
END^

ALTER PROCEDURE REPL$CLONETARGET (REPLNO INTEGER, TGTDBNO INTEGER, NEWREPLNO INTEGER, NEWTGTDBNO INTEGER)
AS
  DECLARE VARIABLE OLDRLNNO INTEGER;
  DECLARE VARIABLE NEWRLNNO INTEGER;
  DECLARE VARIABLE NEWSORTKEY INTEGER;
BEGIN
  if (NOT EXISTS(select * from REPL$subscribeddb where replno = :newreplno and dbno = :newtgtdbno)) then 
  begin
    NEWSORTKEY = 0;
    select MAX(SORT_KEY)+1 FROM REPL$SUBSCRIBEDDB WHERE REPLNO=:NEWREPLNO INTO :NEWSORTKEY;
    insert into REPL$subscribeddb(replno,dbno,username,psword,userrole,UseDefaultLogging,LogFileName,LogToFile,LogToWindow,sort_key)
    select :newreplno,:newtgtdbno,username,psword,userrole,UseDefaultLogging,LogFileName,LogToFile,LogToWindow,:newsortkey from REPL$subscribeddb where replno = :replno and dbno = :tgtdbno;
  end
  FOR SELECT RELATIONNO FROM REPL$RELATIONS WHERE REPLNO = :REPLNO AND TGTDBNO = :TGTDBNO INTO :OLDRLNNO DO 
  BEGIN
    NEWRLNNO = GEN_ID(REPL$RELATIONGEN,1);
    INSERT INTO REPL$RELATIONS (REPLNO,TGTDBNO,RELATIONNO,RELATIONSCHEMA,RELATIONNAME,COMMENTS,DISABLED, TIMEFIELDNAME, CONDITION,TARGETSCHEMA,TARGETNAME,TARGETTYPE,SEP,OPS,SORT_KEY,CONFLICTMETHOD,FKBEHAVIOR)
    SELECT :NEWREPLNO,:NEWTGTDBNO,:NEWRLNNO,RELATIONSCHEMA,RELATIONNAME, COMMENTS, DISABLED, TIMEFIELDNAME, CONDITION, TARGETSCHEMA, TARGETNAME, TARGETTYPE, SEP, OPS, SORT_KEY,CONFLICTMETHOD,FKBEHAVIOR FROM REPL$RELATIONS
      WHERE REPLNO = :REPLNO AND TGTDBNO = :TGTDBNO AND RELATIONNO = :OLDRLNNO;
    INSERT INTO REPL$KEYFIELDS (REPLNO, RELATIONNO, TGTDBNO, FIELDNO, FIELDNAME, TARGETNAME)
    SELECT :NEWREPLNO , :NEWRLNNO , :NEWTGTDBNO, FIELDNO, FIELDNAME, TARGETNAME FROM REPL$KEYFIELDS
      WHERE REPLNO = :REPLNO AND TGTDBNO = :TGTDBNO AND RELATIONNO = :OLDRLNNO;
    INSERT INTO REPL$DATAFIELDS (REPLNO, RELATIONNO, TGTDBNO, FIELDNO, FIELDNAME, TARGETNAME)
    SELECT :NEWREPLNO, :NEWRLNNO, :NEWTGTDBNO, FIELDNO, FIELDNAME, TARGETNAME FROM REPL$DATAFIELDS
      WHERE REPLNO = :REPLNO AND TGTDBNO = :TGTDBNO AND RELATIONNO = :OLDRLNNO;
  END
  INSERT INTO REPL$SEQUENCES (REPLNO,TGTDBNO,SOURCESCHEMA,SOURCENAME,TARGETSCHEMA,TARGETNAME)
    SELECT :NEWREPLNO,:NEWTGTDBNO,SOURCESCHEMA,SOURCENAME,TARGETSCHEMA,TARGETNAME FROM REPL$SEQUENCES
      WHERE REPLNO=:REPLNO AND TGTDBNO=:TGTDBNO;
END^

UPDATE REPL$CONFIG SET VERSION=41^
